prescale_to_u32

Function prescale_to_u32 

pub fn prescale_to_u32(prescale: f32) -> u32
The prescale values are defined by a single u32 This number represents 0 for trigger off and 1.0 for 2**32 - 1 (which is u32::MAX)

The range for the prescale value is [0,1.0]. If the given value is outside of the interval boundaries, it will be converted to the next interval limit